@@ -26,10 +26,10 @@
 #
 
 import sys
-if sys.version_info.major == 2:
-    ModulenotfoundExp_ = ImportError
-else:
+try:
     ModulenotfoundExp_ = ModuleNotFoundError
+except NameError:
+    ModulenotfoundExp_ = ImportError
 from six.moves import zip_longest
 import os
 import re as re_
@@ -221,6 +221,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires integer value')
             return value
         def gds_format_integer_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_integer_list(
                 self, input_data, node=None, input_name=''):
@@ -229,7 +231,7 @@ except ModulenotfoundExp_ as exp:
                 try:
                     int(value)
                 except (TypeError, ValueError):
-                    raise_parse_error(node, 'Requires sequence of integer valuess')
+                    raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
             return ('%.15f' % input_data).rstrip('0')
@@ -246,6 +248,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires float value')
             return value
         def gds_format_float_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_float_list(
                 self, input_data, node=None, input_name=''):
@@ -276,6 +280,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires decimal value')
             return value
         def gds_format_decimal_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return ' '.join([self.gds_format_decimal(item) for item in input_data])
         def gds_validate_decimal_list(
                 self, input_data, node=None, input_name=''):
@@ -287,7 +293,7 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of decimal values')
             return values
         def gds_format_double(self, input_data, input_name=''):
-            return '%e' % input_data
+            return '%s' % input_data
         def gds_parse_double(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -301,6 +307,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires double or float value')
             return value
         def gds_format_double_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_double_list(
                 self, input_data, node=None, input_name=''):
@@ -330,6 +338,8 @@ except ModulenotfoundExp_ as exp:
                     '(one of True, 1, False, 0)')
             return input_data
         def gds_format_boolean_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_boolean_list(
                 self, input_data, node=None, input_name=''):
@@ -781,7 +791,10 @@ def find_attr_value_(attr_name, node):
         value = attrs.get(attr_name)
     elif len(attr_parts) == 2:
         prefix, name = attr_parts
-        namespace = node.nsmap.get(prefix)
+        if prefix == 'xml':
+            namespace = 'http://www.w3.org/XML/1998/namespace'
+        else:
+            namespace = node.nsmap.get(prefix)
         if namespace is not None:
             value = attrs.get('{%s}%s' % (namespace, name, ))
     return value
@@ -963,7 +976,7 @@ def _cast(typ, value):
 class PersonType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('personId', 'PersonIdType1', 0, 0, {'maxOccurs': '1', 'minOccurs': '1', 'name': 'personId', 'ref': 'personId', 'type': 'personId'}, None),
+        MemberSpec_('personId', 'PersonIdType', 0, 0, {'maxOccurs': '1', 'minOccurs': '1', 'name': 'personId', 'ref': 'personId', 'type': 'personId'}, None),
         MemberSpec_('fname', 'xs:string', 0, 0, {'name': 'fname', 'type': 'xs:string'}, None),
         MemberSpec_('lname', 'xs:string', 0, 0, {'name': 'lname', 'type': 'xs:string'}, None),
     ]
@@ -1073,7 +1086,7 @@ class PersonType(GeneratedsSuper):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         if nodeName_ == 'personId':
-            obj_ = PersonIdType1.factory(parent_object_=self)
+            obj_ = PersonIdType.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.personId = obj_
             obj_.original_tagname_ = 'personId'
@@ -1092,10 +1105,10 @@ class PersonType(GeneratedsSuper):
 # end class PersonType
 
 
-class PersonIdType1(GeneratedsSuper):
+class PersonIdType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('valueOf_', ['PersonIdType', 'eitc:IdType'], 0),
+        MemberSpec_('valueOf_', ['PersonIdType_impl', 'IdType', 'xs:integer'], 0),
     ]
     subclass = None
     superclass = None
@@ -1109,13 +1122,13 @@ class PersonIdType1(GeneratedsSuper):
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, PersonIdType1)
+                CurrentSubclassModule_, PersonIdType)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if PersonIdType1.subclass:
-            return PersonIdType1.subclass(*args_, **kwargs_)
+        if PersonIdType.subclass:
+            return PersonIdType.subclass(*args_, **kwargs_)
         else:
-            return PersonIdType1(*args_, **kwargs_)
+            return PersonIdType(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
@@ -1123,6 +1136,16 @@ class PersonIdType1(GeneratedsSuper):
         self.ns_prefix_ = ns_prefix
     def get_valueOf_(self): return self.valueOf_
     def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
+    def validate_PersonIdType_impl(self, value):
+        result = True
+        # Validate type PersonIdType_impl, a restriction on IdType.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, int):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (int)' % {"value": value, "lineno": lineno, })
+                return False
+            pass
+        return result
     def hasContent_(self):
         if (
             (1 if type(self.valueOf_) in [int,float] else self.valueOf_)
@@ -1130,32 +1153,32 @@ class PersonIdType1(GeneratedsSuper):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('PersonIdType1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('PersonIdType')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'PersonIdType1':
+        if self.original_tagname_ is not None and name_ == 'PersonIdType':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PersonIdType1')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PersonIdType')
         if self.hasContent_():
             outfile.write('>')
             outfile.write(self.convert_unicode(self.valueOf_))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PersonIdType1', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PersonIdType', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='PersonIdType1'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='PersonIdType'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType1', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType', fromsubclass_=False, pretty_print=True):
         pass
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
@@ -1173,12 +1196,12 @@ class PersonIdType1(GeneratedsSuper):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         pass
-# end class PersonIdType1
+# end class PersonIdType
 
 
 GDSClassesMapping = {
     'person': PersonType,
-    'personId': PersonIdType1,
+    'personId': PersonIdType,
 }
 
 
@@ -1374,6 +1397,6 @@ RenameMappings_ = {
 NamespaceToDefMappings_ = {}
 
 __all__ = [
-    "PersonIdType1",
+    "PersonIdType",
     "PersonType"
 ]
